@@ -7,11 +7,8 @@
 #include "calendarcontroller.h"
 #include "localcalendar.h"
 #include <QDebug>
-#include <QRegExp>
 #include <QDir>
 #include <QFile>
-#include <QJsonDocument>
-#include <QJsonObject>
 #include <QNetworkRequest>
 #include <QNetworkReply>
 #include <KLocalizedString>
@@ -23,6 +20,7 @@ class CalendarController::Private
 public:
     Private() : config {"kongressrc"}  {};
     KConfig config;
+    QNetworkAccessManager *nam = nullptr;
 };
 
 CalendarController::CalendarController(QObject *parent)
@@ -31,6 +29,11 @@ CalendarController::CalendarController(QObject *parent)
     loadSavedConferences();
 }
 
+void CalendarController::setNetworkAccessManager(QNetworkAccessManager *nam)
+{
+    d->nam = nam;
+}
+
 QString CalendarController::calendars() const
 {
     return d->config.group("general").readEntry("calendars", QString {});
@@ -139,17 +142,15 @@ void CalendarController::createCalendarFromUrl(const QString &calendarId, const
     auto filePath = calendarFile(calendarId);
 
     QNetworkRequest request {url};
-    auto nm = new QNetworkAccessManager {this};
-    nm->get(request);
+    auto reply = d->nam->get(request);
 
-    connect(nm, &QNetworkAccessManager::finished, [this, nm, filePath, calendarId, timeZoneId](QNetworkReply * reply) {
+    connect(reply, &QNetworkReply::finished, [this, reply, filePath, calendarId, timeZoneId]() {
         if (reply->error() == QNetworkReply::NoError) {
             if (saveToDisk(filePath, reply->readAll())) {
                 downloadFinished(calendarId, timeZoneId, filePath);
             }
         }
         reply->deleteLater();
-        nm->deleteLater();
         Q_EMIT downlading(calendarId, false);
     });
 
